@@ -65,7 +65,7 @@ class AppVersionNumberMatcher(RegexMatcher):
             # ex) match 2.10.1-dev+bundle
             RegexBundle(
                 semver.VersionInfo._REGEX.pattern.replace(" ", "").replace(
-                    os.linesep, ""
+                    "\n", ""
                 )
             ),
         ]
