@@ -20,7 +20,7 @@ logger = logging.getLogger(__name__)
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "self-service", "private_app"
+    "splunk_appinspect", "appapproval", "cloud", "self-service", "private_app", "private_victoria", "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.0.0")
 @splunk_appinspect.display(report_display_order=1)
@@ -33,7 +33,14 @@ def check_that_local_does_not_exist(app, reporter):
         reporter.fail(reporter_output)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "self-service", "private_app")
+@splunk_appinspect.tags(
+    "splunk_appinspect",
+    "cloud",
+    "self-service",
+    "private_app",
+    "private_victoria",
+    "private_classic"
+)
 @splunk_appinspect.cert_version(min="1.1.9")
 def check_for_local_meta(app, reporter):
     """Check that the file 'local.meta' does not exist.  All metadata
@@ -48,7 +55,7 @@ def check_for_local_meta(app, reporter):
         reporter.fail(reporter_output, file_path)
 
 
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.1.16")
 def check_that_local_passwords_conf_does_not_exist(app, reporter):
     """Check that `local/passwords.conf` does not exist.  Password files are not
@@ -69,7 +76,14 @@ def check_that_local_passwords_conf_does_not_exist(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "appapproval", "cloud", "private_app")
+@splunk_appinspect.tags(
+    "splunk_appinspect",
+    "appapproval",
+    "cloud",
+    "private_app",
+    "private_victoria",
+    "private_classic"
+)
 @splunk_appinspect.cert_version(min="1.3.2")
 def check_that_directory_name_matches_package_id(app, reporter, included_tags):
     """Check that when decompressed the Splunk app directory name matches the `id` property
@@ -163,7 +177,7 @@ def _is_update_enabled(check_for_updates_value):
         return True
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_filenames_for_spaces(app, reporter):
     """Check that app has no .conf or dashboard filenames that contain spaces.
@@ -182,7 +196,7 @@ def check_filenames_for_spaces(app, reporter):
             reporter.fail(reporter_output)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.6.0")
 def check_that_app_name_config_is_valid(app, reporter):
     """Check that the app name does not start with digits"""
@@ -193,7 +207,7 @@ def check_that_app_name_config_is_valid(app, reporter):
         pass
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.7.0")
 def check_splunklib_dependency_under_bin_folder(app, reporter):
     """Check splunklib dependency should not be placed under app's `bin` folder. Please refer to
