@@ -34,7 +34,7 @@ if not platform.system() == "Windows":
 logger = logging.getLogger(__name__)
 
 
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.1.19")
 def check_default_data_ui_file_white_list(app, reporter):
     """
@@ -128,7 +128,7 @@ def _is_text_with_password_(soup, compiled_regex):
     return False
 
 
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.1.19")
 def check_lookups_white_list(app, reporter):
     """Check that `lookups/` contains only approved file types (.csv,
@@ -179,7 +179,7 @@ def check_lookups_white_list(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "splunk_appinspect", "private_app")
+@splunk_appinspect.tags("cloud", "splunk_appinspect", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.1.19")
 def check_metadata_white_list(app, reporter):
     """Check that the `metadata/` directory only contains .meta files."""
@@ -277,7 +277,7 @@ def check_static_directory_file_white_list(app, reporter):
 # -------------------
 # authorize.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.1.20")
 def check_authorize_conf_admin_all_objects_privileges(app, reporter):
     """Check that authorize.conf does not grant excessive administrative
@@ -326,7 +326,7 @@ def check_authorize_conf_admin_all_objects_privileges(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="2.0.2")
 def check_authorize_conf_for_tokens_auth(app, reporter):
     """Check that authorize.conf does not contain a `tokens_auth` stanza"""
@@ -511,7 +511,7 @@ def _is_python_script(file_path):
 # -------------------
 # distsearch.conf
 # -------------------
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_distsearch_conf_for_concerning_replicated_file_size(app, reporter):
     """Check if concerningReplicatedFileSize in distsearch.conf is larger
@@ -551,7 +551,7 @@ def check_distsearch_conf_for_concerning_replicated_file_size(app, reporter):
 # -------------------
 # indexes.conf
 # -------------------
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.1.20")
 def check_indexes_conf_only_uses_splunk_db_variable(app, reporter):
     """Check that indexes defined in `indexes.conf` use relative paths starting
@@ -601,7 +601,7 @@ def check_indexes_conf_only_uses_splunk_db_variable(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.1.20")
 def check_for_index_volume_usage(app, reporter):
     """Check that `indexes.conf` does not declare volumes."""
@@ -633,7 +633,7 @@ def check_for_index_volume_usage(app, reporter):
 # -------------------
 # inputs.conf
 # -------------------
-@splunk_appinspect.tags("cloud", "inputs_conf", "private_app")
+@splunk_appinspect.tags("cloud", "inputs_conf", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_for_inputs_fifo_usage(app, reporter):
     """Check the `[fifo]` stanza in `inputs.conf` is not pointing to a path
@@ -663,7 +663,7 @@ def check_for_inputs_fifo_usage(app, reporter):
         reporter.not_applicable("The default/inputs.conf does not exist.")
 
 
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.2.1")
 def check_inputs_conf_for_tcp(app, reporter):
     """Check that `default/inputs.conf` or `local/inputs.conf` does not contain a `tcp` stanza."""
@@ -686,7 +686,7 @@ def check_inputs_conf_for_tcp(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.2.1")
 def check_inputs_conf_for_splunk_tcp(app, reporter):
     """Check that `default/inputs.conf` or `local/inputs.conf` does not contain a `splunktcp`
@@ -712,7 +712,7 @@ def check_inputs_conf_for_splunk_tcp(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.2.1")
 def check_inputs_conf_for_fschange(app, reporter):
     """Check that `default/inputs.conf` or `local/inputs.conf` does not contain a `fschange`
@@ -736,7 +736,7 @@ def check_inputs_conf_for_fschange(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "inputs_conf", "private_app")
+@splunk_appinspect.tags("cloud", "inputs_conf", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.2.1")
 def check_inputs_conf_for_http_global_usage(app, reporter):
     """Check that `default/inputs.conf` or `local/inputs.conf` does not contain a `[http]`
@@ -763,7 +763,7 @@ def check_inputs_conf_for_http_global_usage(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "inputs_conf", "private_app")
+@splunk_appinspect.tags("cloud", "inputs_conf", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="2.2.0")
 def check_inputs_conf_for_http_local_stanza_usage(app, reporter):
     """Check that `default/inputs.conf` or `local/inputs.conf` contains accurate `[http://name]`
@@ -792,7 +792,7 @@ def check_inputs_conf_for_http_local_stanza_usage(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.2.1")
 def check_inputs_conf_for_splunktcptoken(app, reporter):
     """Check that `default/inputs.conf` or `local/inputs.conf` does not contain a `splunktcptoken`
@@ -817,7 +817,7 @@ def check_inputs_conf_for_splunktcptoken(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.1")
 def check_inputs_conf_for_batch(app, reporter):
     """Check that batch input accesses files in a permitted way.
@@ -865,7 +865,7 @@ def check_inputs_conf_for_batch(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "splunk_appinspect", "private_app")
+@splunk_appinspect.tags("cloud", "splunk_appinspect", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="2.2.0")
 def check_inputs_conf_batch_has_required_attributes(app, reporter):
     """Check that batch input has required attributes.
@@ -894,7 +894,7 @@ def check_inputs_conf_batch_has_required_attributes(app, reporter):
                 reporter.fail(reporter_output, file_path, section.lineno)
 
 
-@splunk_appinspect.tags("cloud", "splunk_appinspect", "private_app")
+@splunk_appinspect.tags("cloud", "splunk_appinspect", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.2.1")
 def check_inputs_conf_for_udp(app, reporter):
     """Check that inputs.conf does not have any UDP inputs."""
@@ -917,7 +917,7 @@ def check_inputs_conf_for_udp(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_inputs_conf_for_ssl(app, reporter):
     """Check that inputs.conf does not have any SSL inputs."""
@@ -940,7 +940,7 @@ def check_inputs_conf_for_ssl(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="2.0.2")
 def check_inputs_conf_for_remote_queue_monitor(app, reporter):
     """Check that inputs.conf does not have any remote_queue inputs."""
@@ -1026,7 +1026,7 @@ def check_scripted_inputs_cmd_path_pattern(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="2.1.0")
 def check_scripted_inputs_python_version(app, reporter):
     """Check that python version is python3 for scripted inputs defined in inputs.conf."""
@@ -1057,7 +1057,7 @@ def check_scripted_inputs_python_version(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_modular_inputs_scripts_exist_for_cloud(app, reporter):
     """Check that there is a script file in `bin/` for each modular input
@@ -1104,7 +1104,7 @@ def check_modular_inputs_scripts_exist_for_cloud(app, reporter):
 # -------------------
 # setup.xml
 # -------------------
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="2.1.0")
 def check_setup_xml_in_default(app, reporter):
     """Check that `setup.xml` does not exist in the app default folder"""
@@ -1221,7 +1221,7 @@ def check_transforms_conf_for_external_cmd(app, reporter, target_splunk_version)
 # -------------------
 # audit.conf
 # -------------------
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_audit_conf_black_list(app, reporter):
     """Check that app does not contain audit.conf, as it is prohibited in
@@ -1241,7 +1241,7 @@ def check_audit_conf_black_list(app, reporter):
 # -------------------
 # authentication.conf
 # -------------------
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="2.0.0")
 def check_stanza_of_authentication_conf(app, reporter):
     """Check that only role-mapping stanza is allowed in authenticaiton.conf as long as it doesn't map users to a cloud-internal role."""
@@ -1299,7 +1299,7 @@ def check_stanza_of_authentication_conf(app, reporter):
 # -------------------
 # bookmarks.conf
 # -------------------
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="2.0.2")
 def check_bookmarks_conf_black_list(app, reporter):
     """Check that app does not contain bookmarks.conf as this
@@ -1316,7 +1316,7 @@ def check_bookmarks_conf_black_list(app, reporter):
 # -------------------
 # crawl.conf
 # -------------------
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_introspection_of_cloud_filesystem(app, reporter):
     """Check that app does not contain crawl.conf
@@ -1337,7 +1337,7 @@ def check_introspection_of_cloud_filesystem(app, reporter):
 # -------------------
 # datatypesbnf.conf
 # -------------------
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_datatypesbnf_conf_black_list(app, reporter):
     """Check that app does not contain datatypesbnf.conf, as it is prohibited
@@ -1355,7 +1355,7 @@ def check_datatypesbnf_conf_black_list(app, reporter):
 # -------------------
 # default-mode.conf
 # -------------------
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_default_mode_conf_black_list(app, reporter):
     """Check that app does not contain default-mode.conf is as it is
@@ -1376,7 +1376,7 @@ def check_default_mode_conf_black_list(app, reporter):
 # deployment.conf
 # -------------------
 @splunk_appinspect.tags(
-    "splunk_appinspect", "splunk_5_0", "removed_feature", "cloud", "private_app"
+    "splunk_appinspect", "splunk_5_0", "removed_feature", "cloud", "private_app", "private_victoria", "private_classic"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_deployment_conf_black_list(app, reporter):
@@ -1402,7 +1402,7 @@ def check_deployment_conf_black_list(app, reporter):
 # -------------------
 # deploymentclient.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_deploymentclient_conf_black_list(app, reporter):
     """Check that app does not contain deploymentclient.conf as it configures
@@ -1421,7 +1421,7 @@ def check_deploymentclient_conf_black_list(app, reporter):
 # -------------------
 # health.conf
 # -------------------
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="2.0.2")
 def check_health_conf_black_list(app, reporter):
     """Check that app does not contain health.conf as sc_admin is not able
@@ -1439,7 +1439,7 @@ def check_health_conf_black_list(app, reporter):
 # -------------------
 # instance.cfg.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_instance_cfg_conf_black_list(app, reporter):
     """Check that app does not contain instance.cfg.conf. Apps should not
@@ -1458,7 +1458,7 @@ def check_instance_cfg_conf_black_list(app, reporter):
 # -------------------
 # literals.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_literals_conf_black_list(app, reporter):
     """Check that app does not contain literals.conf. Apps should not
@@ -1477,7 +1477,7 @@ def check_literals_conf_black_list(app, reporter):
 # -------------------
 # messages.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_messages_conf_black_list(app, reporter):
     """Check that app does not contain messages.conf. Apps should not
@@ -1496,7 +1496,7 @@ def check_messages_conf_black_list(app, reporter):
 # -------------------
 # passwords.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_that_passwords_conf_not_exist(app, reporter):
     """Check that the app does not have default/passwords.conf, otherwise, warn it."""
@@ -1512,7 +1512,7 @@ def check_that_passwords_conf_not_exist(app, reporter):
 # -------------------
 # props.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_that_no_configurations_of_default_source_type_in_props_conf(app, reporter):
     """Check that the app does not contain configurations of default source type in props.conf,
@@ -1550,7 +1550,7 @@ def check_that_no_configurations_of_default_source_type_in_props_conf(app, repor
 # -------------------
 # pubsub.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_pubsub_conf_black_list(app, reporter):
     """Check that app does not contain pubsub.conf as it defines a custom
@@ -1569,7 +1569,7 @@ def check_pubsub_conf_black_list(app, reporter):
 # -------------------
 # segmenters.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_segmenters_conf_black_list(app, reporter):
     """Check that app does not contain segmenters.conf with splunk stanza. A misconfigured
@@ -1613,7 +1613,7 @@ def check_segmenters_conf_black_list(app, reporter):
 # -------------------
 # serverclass.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_serverclass_conf_black_list(app, reporter):
     """Check that app does not contain serverclass.conf as it defines
@@ -1632,7 +1632,7 @@ def check_serverclass_conf_black_list(app, reporter):
 # -------------------
 # serverclass.seed.xml.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_serverclass_seed_xml_conf_black_list(app, reporter):
     """Check that app does not contain serverclass.seed.xml.conf as it
@@ -1653,7 +1653,7 @@ def check_serverclass_seed_xml_conf_black_list(app, reporter):
 # -------------------
 # source-classifier.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_source_classifier_conf_black_list(app, reporter):
     """Check that app does not contain source-classifier.conf.conf as it
@@ -1672,7 +1672,7 @@ def check_source_classifier_conf_black_list(app, reporter):
 # -------------------
 # sourcetypes.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_sourcetypes_conf_black_list(app, reporter):
     """Check that app does not contain sourcetypes.conf as it is a
@@ -1691,7 +1691,7 @@ def check_sourcetypes_conf_black_list(app, reporter):
 # -------------------
 # splunk-launch.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_splunk_launch_conf_black_list(app, reporter):
     """Check that app does not contain splunk-launch.conf as it defines
@@ -1710,7 +1710,7 @@ def check_splunk_launch_conf_black_list(app, reporter):
 # -------------------
 # telemetry.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "telemetry", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "telemetry", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_telemetry_conf_black_list(app, reporter):
     """Check that app does not contain telemetry.conf as it controls a
@@ -1733,7 +1733,7 @@ def check_telemetry_conf_black_list(app, reporter):
 # -------------------
 # user-seed.conf
 # -------------------
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_user_seed_conf_black_list(app, reporter):
     """Check that app does not contain user-seed.conf as it is used to
@@ -1751,7 +1751,7 @@ def check_user_seed_conf_black_list(app, reporter):
 # -------------------
 # wmi.conf
 # -------------------
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_wmi_conf_black_list(app, reporter):
     """Check that app does not contain wmi.conf is as it is prohibited in
@@ -1771,7 +1771,7 @@ def check_wmi_conf_black_list(app, reporter):
 # -------------------
 # workload_pools.conf
 # -------------------
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="2.0.2")
 def check_workload_pools_conf_black_list(app, reporter):
     """Check that app does not contain workload_pools.conf in Cloud. App should
@@ -1790,7 +1790,7 @@ def check_workload_pools_conf_black_list(app, reporter):
 # -------------------
 # workload_rules.conf
 # -------------------
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="2.0.2")
 def check_workload_rules_conf_black_list(app, reporter):
     """Check that app does not contain workload_rules.conf in Cloud as it
@@ -2094,7 +2094,7 @@ def check_for_java(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_for_implementing_tscollect(app, reporter):
     """Check that use of
@@ -2110,7 +2110,7 @@ def check_for_implementing_tscollect(app, reporter):
         reporter.fail(reporter_output, filepath, lineno)
 
 
-@splunk_appinspect.tags("cloud", "private_app", "future")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic", "future")
 @splunk_appinspect.cert_version(min="2.11.1")
 def check_python_sdk_version(app, reporter):
     """Check that Splunk SDK for Python is up-to-date."""
