@@ -228,7 +228,7 @@ def _combine_messages_in_special_files(
         messages_in_special_files[file_path] = message
 
 
-@splunk_appinspect.tags("splunk_appinspect", "security", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "security", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_for_sensitive_info_in_url(app, reporter):
     """Check for sensitive information being exposed in transit via URL query string parameters"""
@@ -384,7 +384,7 @@ def check_for_environment_variable_use_in_python(app, reporter):
         reporter.fail(reporter_output, filename, line)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "security", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "security", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.2")
 def check_symlink_outside_app(app, reporter):
     """Check no symlink points to the file outside this app"""
@@ -411,3 +411,68 @@ def check_symlink_outside_app(app, reporter):
                         f"File: {app_file_path}"
                     )
                     reporter.fail(reporter_output, app_file_path)
+
+
+# def check_for_supported_tls(app, reporter):
+#     """Check that all outgoing connections use TLS in accordance to Splunk Cloud Platform policy."""
+#     client = app.python_analyzer_client
+#
+#     def _report_if_all_kwrgs_found(
+#         ast_info, file_path, reporter, lib_name, check_kwrgs
+#     ):
+#         usages = ast_info.get_module_function_call_usage(lib_name, fuzzy=True)
+#         for usage in usages:
+#             find_count = 0
+#             if hasattr(usage, "keywords"):
+#                 for keyword in usage.keywords:
+#                     if (
+#                         hasattr(keyword, "arg")
+#                         and hasattr(keyword, "value")
+#                         and hasattr(keyword.value, "value")
+#                     ):
+#                         for k, v in check_kwrgs.items():
+#                             if keyword.arg == k and keyword.value.value == v:
+#                                 find_count = find_count + 1
+#             if find_count == len(check_kwrgs):
+#                 reporter_output = (
+#                     f"If you are using {lib_name} to talk to your own infra with non-public PKI, "
+#                     f"make sure you bundle your own CA certs as part of your app and pass the path "
+#                     f"into {lib_name} as an arg."
+#                 )
+#                 reporter.warn(reporter_output, file_path, usage.lineno)
+#
+#     for file_path, ast_info in client.get_all_ast_infos():
+#         _report_if_all_kwrgs_found(
+#             ast_info,
+#             file_path,
+#             reporter,
+#             "http.client.HTTPSConnection",
+#             {"cert_file": None},
+#         )
+#         _report_if_all_kwrgs_found(
+#             ast_info,
+#             file_path,
+#             reporter,
+#             "urllib.request.urlopen",
+#             {
+#                 "cafile": None,
+#                 "capath": None,
+#             },
+#         )
+#         _report_if_all_kwrgs_found(
+#             ast_info,
+#             file_path,
+#             reporter,
+#             "httplib2.Http",
+#             {"disable_ssl_certificate_validation": False},
+#         )
+#         for request_method in (
+#             "requests.request",
+#             "requests.get",
+#             "requests.post",
+#             "requests.patch",
+#             "requests.put",
+#         ):
+#             _report_if_all_kwrgs_found(
+#                 ast_info, file_path, reporter, request_method, {"verify": False}
+#             )
