@@ -19,7 +19,7 @@ import os
 import splunk_appinspect
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 @splunk_appinspect.display(report_display_order=6)
 def check_web_conf(app, reporter):
