@@ -70,10 +70,11 @@ class ConfigurationSection(object):
 
 
 class ConfigurationFile(object):
-    def __init__(self):
+    def __init__(self, name=None):
         self.headers = []
         self.sects = dict()
         self.errors = []
+        self.name = name
 
     def set_main_headers(self, header):
         self.headers = header
