@@ -344,7 +344,7 @@ def documentation(
     metavar=STRING_META_VAR,
     help=CUSTOM_CHECKS_OPTION_HELP_OUTPUT,
 )
-def report(list_type, included_tags, excluded_tags, custom_checks_dir):
+def report(list_type, included_tags, excluded_tags, custom_checks_dir):  # noqa: C901
     """
     List is used to generate information about Splunk AppInspect.
 
