@@ -1,6 +1,6 @@
-import os.path
-import copy
 import ast
+import copy
+import os.path
 
 
 class Stack(object):
@@ -60,7 +60,7 @@ class FileNode(object):
         return len(self._children)
 
     def __str__(self):
-        return "<FileNode: {}>".format(self.filepath)
+        return f"<FileNode: {self.filepath}>"
 
     def add_parent(self, parent, stamp=None):
         self._parents.add(parent)
@@ -92,7 +92,7 @@ class Copyable(object):
 
 class AstVariable(Copyable):
     """
-        one variable could have more than one variable types
+    one variable could have more than one variable types
     """
 
     # some basic variable types
@@ -240,11 +240,11 @@ class AstClass(Copyable):
 
     # TODO doesn't align with python implementation
     """
-        Python won't copy context from super class to current class, just link them together. So If I change a attribute in super class,
-        inherited class or instances will also be affected. In current implementation, we could not support this feature, since super class and
-        inherited class are isolated environments, they won't affect each other.
+    Python won't copy context from super class to current class, just link them together. So If I change a attribute in super class,
+    inherited class or instances will also be affected. In current implementation, we could not support this feature, since super class and
+    inherited class are isolated environments, they won't affect each other.
 
-        Current design facilitate Analyzer's implementation, make code easy to maintain. Need to refactor these logic when necessary
+    Current design facilitate Analyzer's implementation, make code easy to maintain. Need to refactor these logic when necessary
     """
 
     def __init__(
@@ -461,7 +461,7 @@ class AstBuiltinGetattrFunction(AstBuiltinFunction):
     def __init__(self):
         AstBuiltinFunction.__init__(self, "getattr")
 
-    def action(self, function_node, analyzer, args, keywords, context):
+    def action(self, function_node, analyzer, args, keywords, context):  # noqa: C901
 
         node, attribute_name, default_value = None, None, None
         # check arg first
