@@ -2,8 +2,12 @@
 interfaces that are unique to the Unix operating system, or in some cases to some or many variants of it.
 """
 
-from splunk_appinspect.python_modules_metadata.metadata_common.metadata_consts import TagConsts
-from splunk_appinspect.python_modules_metadata.metadata_common.metadata_decorator import tags
+from splunk_appinspect.python_modules_metadata.metadata_common.metadata_consts import (
+    TagConsts,
+)
+from splunk_appinspect.python_modules_metadata.metadata_common.metadata_decorator import (
+    tags,
+)
 
 
 @tags(TagConsts.UNIX_SPECIFIX_SERVICES)
@@ -13,9 +17,10 @@ def open():
     """
     pass
 
+
 @tags(TagConsts.UNIX_SPECIFIX_SERVICES)
 def fileopen():
     """
     Create a new posixfile object
     """
-    pass
\ No newline at end of file
+    pass
