@@ -1,4 +1,4 @@
 """
 The Web Server Gateway Interface (WSGI) is a standard interface between web server software and web applications written in Python.
 """
-from . import simple_server
\ No newline at end of file
+from . import simple_server  # noqa: F401
