@@ -1,10 +1,9 @@
 # Copyright 2019 Splunk Inc. All rights reserved.
 """Splunk AppInspect Resource Abstraction module. In Splunk AppInspect API service, standalone and clamav resource are provided."""
 
-# Python Standard Libraries
-from collections import defaultdict
 import contextlib
 import threading
+from collections import defaultdict
 
 
 class ResourceManagerContext(object):
@@ -38,9 +37,7 @@ class ResourceManagerContext(object):
                 return self._resources[attrname].resource()
 
             raise KeyError(
-                "No such resource defined in context: {} ([{}])".format(
-                    attrname, self.manager.resource_types.keys()
-                )
+                f"No such resource defined in context: {attrname} ([{self.manager.resource_types.keys()}])"
             )
 
     def __getitem__(self, attrname):
@@ -81,7 +78,7 @@ class ManagedResource(object):
         return self._resource
 
     def setup(self):
-        """ Set up"""
+        """Set up"""
 
     def release(self):
-        """ Clean up """
+        """Clean up"""
