@@ -5,20 +5,16 @@ Splunk's rest map feature.
 """
 
 
-# Python Standard Libraries
-import os
 import logging
+import os
 
-# Custom Libraries
-from . import file_resource
-from . import rest_map_configuration_file
-
+from . import file_resource, rest_map_configuration_file
 
 logger = logging.getLogger(__name__)
 
 
 class RestHandler(object):
-    """ Represents a rest handler. """
+    """Represents a rest handler."""
 
     def __init__(
         self,
@@ -86,7 +82,7 @@ class RestHandler(object):
 
 
 class RestMap(object):
-    """ Represents a restmap.conf file. """
+    """Represents a restmap.conf file."""
 
     def __init__(self, app, directory="default"):
         self.app = app
@@ -210,9 +206,9 @@ class RestMap(object):
                     for member in members:
                         if not member:  # skip ""
                             continue
-                        member_match = "{}/{}".format(
-                            admin_root.strip("/"), member.strip().strip("/")
-                        )
+                        admin_root_strip = admin_root.strip("/")
+                        member_strip = member.strip().strip("/")
+                        member_match = f"{admin_root_strip}/{member_strip}"
                         patterns.append(member_match)
 
         return patterns
